summaryrefslogtreecommitdiff
path: root/WindozeCE
diff options
context:
space:
mode:
authornanbor <nanbor@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-05-05 07:28:49 +0000
committernanbor <nanbor@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1998-05-05 07:28:49 +0000
commit00337247f3a07cc5664f2c356bc7ba86e56defc1 (patch)
treec9d929a0e13d4234db2fd7da884b1a15e6a38e0e /WindozeCE
parent735ca3987751adfb03cd32d73318d99e72b343c0 (diff)
downloadATCD-00337247f3a07cc5664f2c356bc7ba86e56defc1.tar.gz
New CE adapter.
Diffstat (limited to 'WindozeCE')
-rw-r--r--WindozeCE/StdAfx.cpp2
-rw-r--r--WindozeCE/StdAfx.h7
-rw-r--r--WindozeCE/WinAdapter.apsbin20272 -> 0 bytes
-rw-r--r--WindozeCE/WinAdapter.cfg1
-rw-r--r--WindozeCE/WinAdapter.clw41
-rw-r--r--WindozeCE/WinAdapterDlg.cpp138
-rw-r--r--WindozeCE/WindozeCE.apsbin0 -> 34768 bytes
-rw-r--r--WindozeCE/WindozeCE.clw41
-rw-r--r--WindozeCE/WindozeCE.cpp (renamed from WindozeCE/WinAdapter.cpp)141
-rw-r--r--WindozeCE/WindozeCE.dsp377
-rw-r--r--WindozeCE/WindozeCE.h (renamed from WindozeCE/WinAdapter.h)100
-rw-r--r--WindozeCE/WindozeCE.plg18
-rw-r--r--WindozeCE/WindozeCE.rc (renamed from WindozeCE/WinAdapter.rc)351
-rw-r--r--WindozeCE/WindozeCEDlg.cpp156
-rw-r--r--WindozeCE/WindozeCEDlg.h (renamed from WindozeCE/WinAdapterDlg.h)108
-rw-r--r--WindozeCE/resource.h12
-rw-r--r--WindozeCE/windoze.cfg1
-rw-r--r--WindozeCE/windoze.dsp413
-rw-r--r--WindozeCE/windoze.dsw29
19 files changed, 953 insertions, 983 deletions
diff --git a/WindozeCE/StdAfx.cpp b/WindozeCE/StdAfx.cpp
index 411e7cbf607..ee3447570e6 100644
--- a/WindozeCE/StdAfx.cpp
+++ b/WindozeCE/StdAfx.cpp
@@ -1,6 +1,6 @@
// $Id$
// stdafx.cpp : source file that includes just the standard includes
-// WinAdapter.pch will be the pre-compiled header
+// WindozeCE.pch will be the pre-compiled header
// stdafx.obj will contain the pre-compiled type information
#include "stdafx.h"
diff --git a/WindozeCE/StdAfx.h b/WindozeCE/StdAfx.h
index e9d1feff454..cb29f2a1b1f 100644
--- a/WindozeCE/StdAfx.h
+++ b/WindozeCE/StdAfx.h
@@ -4,8 +4,8 @@
// are changed infrequently
//
-#if !defined(AFX_STDAFX_H__5088F84A_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
-#define AFX_STDAFX_H__5088F84A_CE8B_11D1_9621_0040054CF0F0__INCLUDED_
+#if !defined(AFX_STDAFX_H__37544C6D_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)
+#define AFX_STDAFX_H__37544C6D_E3BC_11D1_968E_0040054CF0F0__INCLUDED_
#if _MSC_VER >= 1000
#pragma once
@@ -19,7 +19,8 @@
#include <afxcmn.h> // MFC support for Windows Common Controls
#endif // _AFX_NO_AFXCMN_SUPPORT
+
//{{AFX_INSERT_LOCATION}}
// Microsoft Developer Studio will insert additional declarations immediately before the previous line.
-#endif // !defined(AFX_STDAFX_H__5088F84A_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
+#endif // !defined(AFX_STDAFX_H__37544C6D_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)
diff --git a/WindozeCE/WinAdapter.aps b/WindozeCE/WinAdapter.aps
deleted file mode 100644
index 1fd97572fe9..00000000000
--- a/WindozeCE/WinAdapter.aps
+++ /dev/null
Binary files differ
diff --git a/WindozeCE/WinAdapter.cfg b/WindozeCE/WinAdapter.cfg
deleted file mode 100644
index 80c479b3205..00000000000
--- a/WindozeCE/WinAdapter.cfg
+++ /dev/null
@@ -1 +0,0 @@
-WCE_CFG=WCE200; \ No newline at end of file
diff --git a/WindozeCE/WinAdapter.clw b/WindozeCE/WinAdapter.clw
deleted file mode 100644
index e2c28626ab3..00000000000
--- a/WindozeCE/WinAdapter.clw
+++ /dev/null
@@ -1,41 +0,0 @@
-; CLW file contains information for the MFC ClassWizard
-
-[General Info]
-Version=1
-LastClass=CWinAdapterDlg
-LastTemplate=CDialog
-NewFileInclude1=#include "stdafx.h"
-NewFileInclude2=#include "WinAdapter.h"
-
-ClassCount=2
-Class1=CWinAdapterApp
-Class2=CWinAdapterDlg
-
-ResourceCount=3
-Resource2=IDR_MAINFRAME
-Resource3=IDD_WinAdapter_DIALOG
-
-[CLS:CWinAdapterApp]
-Type=0
-HeaderFile=WinAdapter.h
-ImplementationFile=WinAdapter.cpp
-Filter=N
-
-[CLS:CWinAdapterDlg]
-Type=0
-HeaderFile=WinAdapterDlg.h
-ImplementationFile=WinAdapterDlg.cpp
-Filter=D
-BaseClass=CDialog
-VirtualFilter=dWC
-LastObject=IDC_TEXT_DISP
-
-
-[DLG:IDD_WinAdapter_DIALOG]
-Type=1
-Class=CWinAdapterDlg
-ControlCount=3
-Control1=IDC_TEXT_DISP,static,1342308352
-Control2=IDC_CMDLINE,edit,1350631552
-Control3=IDC_START,button,1342242817
-
diff --git a/WindozeCE/WinAdapterDlg.cpp b/WindozeCE/WinAdapterDlg.cpp
deleted file mode 100644
index de603c72ad5..00000000000
--- a/WindozeCE/WinAdapterDlg.cpp
+++ /dev/null
@@ -1,138 +0,0 @@
-// $Id$
-// WinAdapterDlg.cpp : implementation file
-//
-
-#include "stdafx.h"
-#include "WinAdapter.h"
-#include "WinAdapterDlg.h"
-#include "ace/ARGV.h"
-#include "ACEApp.h"
-
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-#endif
-
-static CWnd *host_window_ = 0;
-
-UINT worker (void * arg)
-{
- ACE_ARGV cmd_line ((TCHAR *) arg);
- extern int ace_ce_main (int, ASYS_TCHAR *[]);
-
- int retv = ace_ce_main (cmd_line.argc (), cmd_line.argv ());
- host_window_->SetDlgItemText (IDC_START, TEXT ("Stopped"));
-
- return retv;
-
-// Sleep (500);
-// for (size_t i = 0; i < cmd_line.argc (); i++, Sleep (500))
-// ACE_DEBUG ((LM_DEBUG, TEXT ("The %d command arg is \"%s\""),
-// i, cmd_line.argv ()[i]));
-
-// return 0;
-// CString *msg = 0;
-// while (1)
-// {
-// Sleep (500);
-// msg = new CString;
-// SYSTEMTIME curtime;
-// GetLocalTime (&curtime);
-// msg->Format (TEXT ("Time: %02d:%02d:%02d.%03d"), curtime.wHour,
-// curtime.wMinute, curtime.wSecond,
-// curtime.wMilliseconds);
-// ACE_DEBUG ((LM_DEBUG, TEXT ("(%P|%t) Test logging: %s\n"), *msg));
-// delete msg;
-// }
-// return 0;
-}
-
-
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterDlg dialog
-
-CWinAdapterDlg::CWinAdapterDlg(CWnd* pParent /*=NULL*/)
- : CDialog(CWinAdapterDlg::IDD, pParent)
-{
- //{{AFX_DATA_INIT(CWinAdapterDlg)
- // NOTE: the ClassWizard will add member initialization here
- //}}AFX_DATA_INIT
- // Note that LoadIcon does not require a subsequent DestroyIcon in Win32
- m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
-}
-
-void CWinAdapterDlg::DoDataExchange(CDataExchange* pDX)
-{
- CDialog::DoDataExchange(pDX);
- //{{AFX_DATA_MAP(CWinAdapterDlg)
- // NOTE: the ClassWizard will add DDX and DDV calls here
- //}}AFX_DATA_MAP
-}
-
-BEGIN_MESSAGE_MAP(CWinAdapterDlg, CDialog)
- //{{AFX_MSG_MAP(CWinAdapterDlg)
- ON_WM_TIMER()
- ON_BN_CLICKED(IDC_START, OnStart)
- //}}AFX_MSG_MAP
-END_MESSAGE_MAP()
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterDlg message handlers
-
-BOOL CWinAdapterDlg::OnInitDialog()
-{
- CDialog::OnInitDialog();
-
- // Set the icon for this dialog. The framework does this automatically
- // when the application's main window is not a dialog
- SetIcon(m_hIcon, TRUE); // Set big icon
- SetIcon(m_hIcon, FALSE); // Set small icon
-
- this->SetDlgItemText (IDC_TEXT_DISP,
- TEXT ("A really long string that will hopefully show whether this kind of string can be fit and wrap around a simple TEXT object within a Dialog box. If this doesn't work, we'll see what to do next."));
- CenterWindow(GetDesktopWindow()); // center to the hpc screen
-
- this->ace.set_window (this, NC_ACE_NOTIFY, INC_ACE_LOGMSG);
- this->ace.set_self_default ();
- host_window_ = this;
- return TRUE; // return TRUE unless you set the focus to a control
-}
-
-void CWinAdapterDlg::OnTimer(UINT nIDEvent)
-{
-// CWnd *text = this->GetDlgItem (IDC_TEXT_DISP);
-// text->ModifyStyle (WS_VISIBLE, SS_CENTER, 0);
-// this->UpdateWindow ();
-}
-
-BOOL CWinAdapterDlg::OnCommand(WPARAM wParam, LPARAM lParam)
-{
- static BOOL got_cmd = FALSE;
- int notify = HIBYTE (wParam);
- int id = LOBYTE (wParam);
-
- if (notify == NC_ACE_NOTIFY && id == INC_ACE_LOGMSG)
- {
- CString *msg = (CString *) lParam ;
- this->SetDlgItemText (IDC_TEXT_DISP, *msg);
- delete msg;
- return TRUE;
- }
- return CDialog::OnCommand(wParam, lParam);
-}
-
-void CWinAdapterDlg::OnStart()
-{
- static BOOL once = FALSE;
-
- if (! once)
- {
- CString cmdline;
- this->GetDlgItemText (IDC_CMDLINE, cmdline);
- AfxBeginThread (worker, (void *) (LPCTSTR) cmdline);
- this->SetDlgItemText (IDC_START, TEXT ("Running..."));
- once = TRUE;
- }
-}
diff --git a/WindozeCE/WindozeCE.aps b/WindozeCE/WindozeCE.aps
new file mode 100644
index 00000000000..0f2688cf3cd
--- /dev/null
+++ b/WindozeCE/WindozeCE.aps
Binary files differ
diff --git a/WindozeCE/WindozeCE.clw b/WindozeCE/WindozeCE.clw
new file mode 100644
index 00000000000..eca2fb8b2d8
--- /dev/null
+++ b/WindozeCE/WindozeCE.clw
@@ -0,0 +1,41 @@
+; CLW file contains information for the MFC ClassWizard
+
+[General Info]
+Version=1
+LastClass=CWindozeCEDlg
+LastTemplate=CDialog
+NewFileInclude1=#include "stdafx.h"
+NewFileInclude2=#include "WindozeCE.h"
+
+ClassCount=2
+Class1=CWindozeCEApp
+Class2=CWindozeCEDlg
+
+ResourceCount=3
+Resource2=IDR_MAINFRAME
+Resource3=IDD_WINDOZECE_DIALOG
+
+[CLS:CWindozeCEApp]
+Type=0
+HeaderFile=WindozeCE.h
+ImplementationFile=WindozeCE.cpp
+Filter=N
+
+[CLS:CWindozeCEDlg]
+Type=0
+HeaderFile=WindozeCEDlg.h
+ImplementationFile=WindozeCEDlg.cpp
+Filter=D
+BaseClass=CDialog
+VirtualFilter=dWC
+LastObject=IDC_RUN
+
+
+[DLG:IDD_WINDOZECE_DIALOG]
+Type=1
+Class=CWindozeCEDlg
+ControlCount=3
+Control1=IDC_PROGRAM_OUTPUT,edit,1352730692
+Control2=IDC_RUN,button,1342242817
+Control3=IDC_PROGRAM_ARGUMENTS,edit,1350631552
+
diff --git a/WindozeCE/WindozeCE.dsp b/WindozeCE/WindozeCE.dsp
new file mode 100644
index 00000000000..6212adfb4cb
--- /dev/null
+++ b/WindozeCE/WindozeCE.dsp
@@ -0,0 +1,377 @@
+# Microsoft Developer Studio Project File - Name="WindozeCE" - Package Owner=<4>
+# Microsoft Developer Studio Generated Build File, Format Version 5.00
+# ** DO NOT EDIT **
+
+# TARGTYPE "Win32 (WCE x86em) Application" 0x0b01
+# TARGTYPE "Win32 (WCE MIPS) Application" 0x0a01
+# TARGTYPE "Win32 (WCE SH) Application" 0x0901
+
+CFG=WindozeCE - Win32 (WCE MIPS) Debug
+!MESSAGE This is not a valid makefile. To build this project using NMAKE,
+!MESSAGE use the Export Makefile command and run
+!MESSAGE
+!MESSAGE NMAKE /f "WindozeCE.mak".
+!MESSAGE
+!MESSAGE You can specify a configuration when running NMAKE
+!MESSAGE by defining the macro CFG on the command line. For example:
+!MESSAGE
+!MESSAGE NMAKE /f "WindozeCE.mak" CFG="WindozeCE - Win32 (WCE MIPS) Debug"
+!MESSAGE
+!MESSAGE Possible choices for configuration are:
+!MESSAGE
+!MESSAGE "WindozeCE - Win32 (WCE MIPS) Release" (based on\
+ "Win32 (WCE MIPS) Application")
+!MESSAGE "WindozeCE - Win32 (WCE MIPS) Debug" (based on\
+ "Win32 (WCE MIPS) Application")
+!MESSAGE "WindozeCE - Win32 (WCE x86em) Release" (based on\
+ "Win32 (WCE x86em) Application")
+!MESSAGE "WindozeCE - Win32 (WCE x86em) Debug" (based on\
+ "Win32 (WCE x86em) Application")
+!MESSAGE "WindozeCE - Win32 (WCE SH) Release" (based on\
+ "Win32 (WCE SH) Application")
+!MESSAGE "WindozeCE - Win32 (WCE SH) Debug" (based on\
+ "Win32 (WCE SH) Application")
+!MESSAGE
+
+# Begin Project
+# PROP Scc_ProjName ""
+# PROP Scc_LocalPath ""
+# PROP WCE_Configuration "H/PC Ver. 2.00"
+
+!IF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Release"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "WMIPSRel"
+# PROP BASE Intermediate_Dir "WMIPSRel"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "WMIPSRel"
+# PROP Intermediate_Dir "WMIPSRel"
+# PROP Target_Dir ""
+CPP=clmips.exe
+# ADD BASE CPP /nologo /MT /W3 /GX- /O2 /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "NDEBUG" /D "MIPS" /D "_MIPS_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /QMRWCE /c
+# ADD CPP /nologo /MT /W3 /GX- /O2 /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "NDEBUG" /D "MIPS" /D "_MIPS_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /QMRWCE /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /r /d "MIPS" /d "_MIPS_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "NDEBUG" /d "_AFXDLL"
+# ADD RSC /l 0x409 /r /d "MIPS" /d "_MIPS_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "NDEBUG" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /machine:MIPS /subsystem:$(CESubsystem)
+# SUBTRACT BASE LINK32 /pdb:none /nodefaultlib
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /machine:MIPS /subsystem:$(CESubsystem)
+# SUBTRACT LINK32 /pdb:none /nodefaultlib
+PFILE=pfile.exe
+# ADD BASE PFILE COPY
+# ADD PFILE COPY
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Debug"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "WMIPSDbg"
+# PROP BASE Intermediate_Dir "WMIPSDbg"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "WMIPSDbg"
+# PROP Intermediate_Dir "WMIPSDbg"
+# PROP Target_Dir ""
+CPP=clmips.exe
+# ADD BASE CPP /nologo /MTd /W3 /GX- /Zi /Od /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "DEBUG" /D "MIPS" /D "_MIPS_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /QMRWCE /c
+# ADD CPP /nologo /MTd /W3 /GX- /Zi /Od /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "DEBUG" /D "MIPS" /D "_MIPS_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /QMRWCE /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /r /d "MIPS" /d "_MIPS_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "DEBUG" /d "_AFXDLL"
+# ADD RSC /l 0x409 /r /d "MIPS" /d "_MIPS_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "DEBUG" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /debug /machine:MIPS /subsystem:$(CESubsystem)
+# SUBTRACT BASE LINK32 /pdb:none /nodefaultlib
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /debug /machine:MIPS /subsystem:$(CESubsystem)
+# SUBTRACT LINK32 /pdb:none /nodefaultlib
+PFILE=pfile.exe
+# ADD BASE PFILE COPY
+# ADD PFILE COPY
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Release"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "x86emRel"
+# PROP BASE Intermediate_Dir "x86emRel"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "x86emRel"
+# PROP Intermediate_Dir "x86emRel"
+# PROP Target_Dir ""
+CPP=cl.exe
+# ADD BASE CPP /nologo /MT /W3 /GX- /O2 /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "NDEBUG" /D "x86" /D "i486" /D "_x86_" /D "_AFXDLL" /Yu"stdafx.h" /c
+# ADD CPP /nologo /MT /W3 /GX- /O2 /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "NDEBUG" /D "x86" /D "i486" /D "_x86_" /D "_AFXDLL" /Yu"stdafx.h" /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /d UNDER_CE=$(CEVersion) /d "UNICODE" /d "_UNICODE" /d "WIN32" /d "STRICT" /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "_WIN32_WCE_EMULATION" /d "INTERNATIONAL" /d "USA" /d "INTLMSG_CODEPAGE" /d "NDEBUG" /d "_AFXDLL"
+# ADD RSC /l 0x409 /d UNDER_CE=$(CEVersion) /d "UNICODE" /d "_UNICODE" /d "WIN32" /d "STRICT" /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "_WIN32_WCE_EMULATION" /d "INTERNATIONAL" /d "USA" /d "INTLMSG_CODEPAGE" /d "NDEBUG" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /subsystem:windows /machine:I386 /windowsce:emulation
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /subsystem:windows /machine:I386 /windowsce:emulation
+EMPFILE=empfile.exe
+# ADD BASE EMPFILE -COPY
+# ADD EMPFILE -COPY
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Debug"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "x86emDbg"
+# PROP BASE Intermediate_Dir "x86emDbg"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "x86emDbg"
+# PROP Intermediate_Dir "x86emDbg"
+# PROP Target_Dir ""
+CPP=cl.exe
+# ADD BASE CPP /nologo /MTd /W3 /Gm /GX- /Zi /Od /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "_DEBUG" /D "x86" /D "i486" /D "_x86_" /D "_AFXDLL" /Yu"stdafx.h" /c
+# ADD CPP /nologo /MTd /W3 /Gm /GX- /Zi /Od /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "_DEBUG" /D "x86" /D "i486" /D "_x86_" /D "_AFXDLL" /Yu"stdafx.h" /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /d UNDER_CE=$(CEVersion) /d "UNICODE" /d "_UNICODE" /d "WIN32" /d "STRICT" /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "_WIN32_WCE_EMULATION" /d "INTERNATIONAL" /d "USA" /d "INTLMSG_CODEPAGE" /d "_DEBUG" /d "x86" /d "i486" /d "_x86_" /d "_AFXDLL"
+# ADD RSC /l 0x409 /d UNDER_CE=$(CEVersion) /d "UNICODE" /d "_UNICODE" /d "WIN32" /d "STRICT" /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "_WIN32_WCE_EMULATION" /d "INTERNATIONAL" /d "USA" /d "INTLMSG_CODEPAGE" /d "_DEBUG" /d "x86" /d "i486" /d "_x86_" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /subsystem:windows /debug /machine:I386 /windowsce:emulation
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /subsystem:windows /debug /machine:I386 /windowsce:emulation
+EMPFILE=empfile.exe
+# ADD BASE EMPFILE -COPY
+# ADD EMPFILE -COPY
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Release"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 0
+# PROP BASE Output_Dir "WCESHRel"
+# PROP BASE Intermediate_Dir "WCESHRel"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 0
+# PROP Output_Dir "WCESHRel"
+# PROP Intermediate_Dir "WCESHRel"
+# PROP Target_Dir ""
+CPP=shcl.exe
+# ADD BASE CPP /nologo /MT /W3 /GX- /O2 /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "NDEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /c
+# ADD CPP /nologo /MT /W3 /GX- /O2 /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "NDEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /r /d "SHx" /d "SH3" /d "_SH3_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "NDEBUG" /d "_AFXDLL"
+# ADD RSC /l 0x409 /r /d "SHx" /d "SH3" /d "_SH3_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "NDEBUG" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /machine:SH3 /subsystem:$(CESubsystem)
+# SUBTRACT BASE LINK32 /pdb:none /nodefaultlib
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /machine:SH3 /subsystem:$(CESubsystem)
+# SUBTRACT LINK32 /pdb:none /nodefaultlib
+PFILE=pfile.exe
+# ADD BASE PFILE COPY
+# ADD PFILE COPY
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Debug"
+
+# PROP BASE Use_MFC 2
+# PROP BASE Use_Debug_Libraries 1
+# PROP BASE Output_Dir "WCESHDbg"
+# PROP BASE Intermediate_Dir "WCESHDbg"
+# PROP BASE Target_Dir ""
+# PROP Use_MFC 2
+# PROP Use_Debug_Libraries 1
+# PROP Output_Dir "WCESHDbg"
+# PROP Intermediate_Dir "WCESHDbg"
+# PROP Target_Dir ""
+CPP=shcl.exe
+# ADD BASE CPP /nologo /MTd /W3 /GX- /Zi /Od /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "DEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /c
+# ADD CPP /nologo /MTd /W3 /GX- /Zi /Od /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "DEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_AFXDLL" /Yu"stdafx.h" /c
+RSC=rc.exe
+# ADD BASE RSC /l 0x409 /r /d "SHx" /d "SH3" /d "_SH3_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "DEBUG" /d "_AFXDLL"
+# ADD RSC /l 0x409 /r /d "SHx" /d "SH3" /d "_SH3_" /d UNDER_CE=$(CEVersion) /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "UNICODE" /d "DEBUG" /d "_AFXDLL"
+MTL=midl.exe
+# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /o NUL /win32
+BSC32=bscmake.exe
+# ADD BASE BSC32 /nologo
+# ADD BSC32 /nologo
+LINK32=link.exe
+# ADD BASE LINK32 /nologo /entry:"wWinMainCRTStartup" /debug /machine:SH3 /subsystem:$(CESubsystem)
+# SUBTRACT BASE LINK32 /pdb:none /nodefaultlib
+# ADD LINK32 /nologo /entry:"wWinMainCRTStartup" /debug /machine:SH3 /subsystem:$(CESubsystem)
+# SUBTRACT LINK32 /pdb:none /nodefaultlib
+PFILE=pfile.exe
+# ADD BASE PFILE COPY
+# ADD PFILE COPY
+
+!ENDIF
+
+# Begin Target
+
+# Name "WindozeCE - Win32 (WCE MIPS) Release"
+# Name "WindozeCE - Win32 (WCE MIPS) Debug"
+# Name "WindozeCE - Win32 (WCE x86em) Release"
+# Name "WindozeCE - Win32 (WCE x86em) Debug"
+# Name "WindozeCE - Win32 (WCE SH) Release"
+# Name "WindozeCE - Win32 (WCE SH) Debug"
+# Begin Group "Source Files"
+
+# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
+# Begin Source File
+
+SOURCE=.\StdAfx.cpp
+
+!IF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Release"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Debug"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Release"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Debug"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Release"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Debug"
+
+# ADD CPP /Yc"stdafx.h"
+
+!ENDIF
+
+# End Source File
+# Begin Source File
+
+SOURCE=.\WindozeCE.cpp
+
+!IF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Debug"
+
+!ENDIF
+
+# End Source File
+# Begin Source File
+
+SOURCE=.\WindozeCE.rc
+
+!IF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Debug"
+
+!ENDIF
+
+# End Source File
+# Begin Source File
+
+SOURCE=.\WindozeCEDlg.cpp
+
+!IF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE MIPS) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE x86em) Debug"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Release"
+
+!ELSEIF "$(CFG)" == "WindozeCE - Win32 (WCE SH) Debug"
+
+!ENDIF
+
+# End Source File
+# End Group
+# Begin Group "Header Files"
+
+# PROP Default_Filter "h;hpp;hxx;hm;inl"
+# Begin Source File
+
+SOURCE=.\Resource.h
+# End Source File
+# Begin Source File
+
+SOURCE=.\StdAfx.h
+# End Source File
+# Begin Source File
+
+SOURCE=.\WindozeCE.h
+# End Source File
+# Begin Source File
+
+SOURCE=.\WindozeCEDlg.h
+# End Source File
+# End Group
+# Begin Group "Resource Files"
+
+# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;cnt;rtf;gif;jpg;jpeg;jpe"
+# Begin Source File
+
+SOURCE=.\res\WindozeCE.ico
+# End Source File
+# Begin Source File
+
+SOURCE=.\res\WindozeCE.rc2
+# PROP Exclude_From_Scan -1
+# PROP BASE Exclude_From_Build 1
+# PROP Exclude_From_Build 1
+# End Source File
+# End Group
+# Begin Source File
+
+SOURCE=.\ReadMe.txt
+# End Source File
+# End Target
+# End Project
diff --git a/WindozeCE/WindozeCE.plg b/WindozeCE/WindozeCE.plg
new file mode 100644
index 00000000000..5eec2c4acbd
--- /dev/null
+++ b/WindozeCE/WindozeCE.plg
@@ -0,0 +1,18 @@
+--------------------Configuration: WindozeCE - Win32 (WCE x86em) Debug--------------------
+Begining build with project "C:\Nanbor\WinCE\WindozeCE\WindozeCE.dsp", at root.
+Active configuration is Win32 (WCE x86em) Application (based on Win32 (WCE x86em) Application)
+
+Project's tools are:
+ "32-bit C/C++ Compiler for 80x86em" with flags "/nologo /MTd /W3 /Gm /Zi /Od /D UNDER_CE=$(CEVersion) /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=$(CEVersion) /D "$(CEConfigName)" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "_DEBUG" /D "x86" /D "i486" /D "_x86_" /D "_AFXDLL" /Fp"x86emDbg/WindozeCE.pch" /Yu"stdafx.h" /Fo"x86emDbg/" /Fd"x86emDbg/" /c "
+ "Win32 Resource Compiler" with flags "/l 0x409 /fo"x86emDbg/WindozeCE.res" /d UNDER_CE=$(CEVersion) /d "UNICODE" /d "_UNICODE" /d "WIN32" /d "STRICT" /d _WIN32_WCE=$(CEVersion) /d "$(CEConfigName)" /d "_WIN32_WCE_EMULATION" /d "INTERNATIONAL" /d "USA" /d "INTLMSG_CODEPAGE" /d "_DEBUG" /d "x86" /d "i486" /d "_x86_" /d "_AFXDLL" "
+ "OLE Type Library Maker" with flags "/nologo /D "_DEBUG" /mktyplib203 /o NUL /win32 "
+ "Browser Database Maker" with flags "/nologo /o"x86emDbg/WindozeCE.bsc" "
+ "COFF Linker for 80x86em" with flags "/nologo /entry:"wWinMainCRTStartup" /subsystem:windows /incremental:yes /pdb:"x86emDbg/WindozeCE.pdb" /debug /machine:I386 /out:"x86emDbg/WindozeCE.exe" /windowsce:emulation "
+ "Empfile Utility" with flags "-COPY "
+ "Custom Build" with flags ""
+ "<Component 0xa>" with flags ""
+
+
+
+
+WindozeCE.exe - 0 error(s), 0 warning(s)
diff --git a/WindozeCE/WinAdapter.rc b/WindozeCE/WindozeCE.rc
index 7e182239ad9..ff78591cb9c 100644
--- a/WindozeCE/WinAdapter.rc
+++ b/WindozeCE/WindozeCE.rc
@@ -1,175 +1,176 @@
-//Microsoft Developer Studio generated resource script.
-//
-#include "resource.h"
-
-#define APSTUDIO_READONLY_SYMBOLS
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 2 resource.
-//
-#include "afxres.h"
-
-/////////////////////////////////////////////////////////////////////////////
-#undef APSTUDIO_READONLY_SYMBOLS
-
-/////////////////////////////////////////////////////////////////////////////
-// English (U.S.) resources
-
-#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
-#ifdef _WIN32
-LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
-#pragma code_page(1252)
-#endif //_WIN32
-
-#ifdef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// TEXTINCLUDE
-//
-
-1 TEXTINCLUDE DISCARDABLE
-BEGIN
- "resource.h\0"
-END
-
-2 TEXTINCLUDE DISCARDABLE
-BEGIN
- "#include ""afxres.h""\r\n"
- "\0"
-END
-
-3 TEXTINCLUDE DISCARDABLE
-BEGIN
- "#define _AFX_NO_SPLITTER_RESOURCES\r\n"
- "#define _AFX_NO_OLE_RESOURCES\r\n"
- "#define _AFX_NO_TRACKER_RESOURCES\r\n"
- "#define _AFX_NO_PROPERTY_RESOURCES\r\n"
- "\r\n"
- "#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)\r\n"
- "#ifdef _WIN32\r\n"
- "LANGUAGE 9, 1\r\n"
- "#pragma code_page(1252)\r\n"
- "#endif\r\n"
- "#include ""res\\WinAdapter.rc2"" // non-Microsoft Visual C++ edited resources\r\n"
- "#include ""afxres.rc"" // Standard components\r\n"
- "#include ""wceres.rc"" // WCE-specific components\r\n"
- "#endif\0"
-END
-
-#endif // APSTUDIO_INVOKED
-
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// Dialog
-//
-
-IDD_WinAdapter_DIALOG DIALOGEX 0, 0, 185, 92
-STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
-EXSTYLE WS_EX_APPWINDOW | WS_EX_CAPTIONOKBTN
-CAPTION "ACE Test"
-FONT 8, "MS Sans Serif"
-BEGIN
- LTEXT "Arguments:",IDC_TEXT_DISP,7,7,171,64
- EDITTEXT IDC_CMDLINE,7,71,118,14,ES_AUTOHSCROLL
- DEFPUSHBUTTON "Start",IDC_START,128,71,50,14
-END
-
-
-#ifndef _MAC
-/////////////////////////////////////////////////////////////////////////////
-//
-// Version
-//
-
-VS_VERSION_INFO VERSIONINFO
- FILEVERSION 1,0,0,1
- PRODUCTVERSION 1,0,0,1
- FILEFLAGSMASK 0x3fL
-#ifdef _DEBUG
- FILEFLAGS 0x1L
-#else
- FILEFLAGS 0x0L
-#endif
- FILEOS 0x4L
- FILETYPE 0x1L
- FILESUBTYPE 0x0L
-BEGIN
- BLOCK "StringFileInfo"
- BEGIN
- BLOCK "040904B0"
- BEGIN
- VALUE "CompanyName", "\0"
- VALUE "FileDescription", "WinAdapter WCE MFC Application\0"
- VALUE "FileVersion", "1, 0, 0, 1\0"
- VALUE "InternalName", "WinAdapter\0"
- VALUE "LegalCopyright", "Copyright (C) 1998\0"
- VALUE "LegalTrademarks", "\0"
- VALUE "OriginalFilename", "WinAdapter.EXE\0"
- VALUE "ProductName", "WinAdapter Application\0"
- VALUE "ProductVersion", "1, 0, 0, 1\0"
- END
- END
- BLOCK "VarFileInfo"
- BEGIN
- VALUE "Translation", 0x409, 1200
- END
-END
-
-#endif // !_MAC
-
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// DESIGNINFO
-//
-
-#ifdef APSTUDIO_INVOKED
-GUIDELINES DESIGNINFO DISCARDABLE
-BEGIN
- IDD_WinAdapter_DIALOG, DIALOG
- BEGIN
- LEFTMARGIN, 7
- RIGHTMARGIN, 178
- TOPMARGIN, 7
- BOTTOMMARGIN, 85
- END
-END
-#endif // APSTUDIO_INVOKED
-
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// Icon
-//
-
-// Icon with lowest ID value placed first to ensure application icon
-// remains consistent on all systems.
-IDR_MAINFRAME ICON DISCARDABLE "res\\WinAdapter.ico"
-#endif // English (U.S.) resources
-/////////////////////////////////////////////////////////////////////////////
-
-
-
-#ifndef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 3 resource.
-//
-#define _AFX_NO_SPLITTER_RESOURCES
-#define _AFX_NO_OLE_RESOURCES
-#define _AFX_NO_TRACKER_RESOURCES
-#define _AFX_NO_PROPERTY_RESOURCES
-
-#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
-#ifdef _WIN32
-LANGUAGE 9, 1
-#pragma code_page(1252)
-#endif
-#include "res\WinAdapter.rc2" // non-Microsoft Visual C++ edited resources
-#include "afxres.rc" // Standard components
-#include "wceres.rc" // WCE-specific components
-#endif
-/////////////////////////////////////////////////////////////////////////////
-#endif // not APSTUDIO_INVOKED
-
+//Microsoft Developer Studio generated resource script.
+//
+#include "resource.h"
+
+#define APSTUDIO_READONLY_SYMBOLS
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 2 resource.
+//
+#include "afxres.h"
+
+/////////////////////////////////////////////////////////////////////////////
+#undef APSTUDIO_READONLY_SYMBOLS
+
+/////////////////////////////////////////////////////////////////////////////
+// English (U.S.) resources
+
+#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
+#ifdef _WIN32
+LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
+#pragma code_page(1252)
+#endif //_WIN32
+
+#ifdef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
+//
+// TEXTINCLUDE
+//
+
+1 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "resource.h\0"
+END
+
+2 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "#include ""afxres.h""\r\n"
+ "\0"
+END
+
+3 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "#define _AFX_NO_SPLITTER_RESOURCES\r\n"
+ "#define _AFX_NO_OLE_RESOURCES\r\n"
+ "#define _AFX_NO_TRACKER_RESOURCES\r\n"
+ "#define _AFX_NO_PROPERTY_RESOURCES\r\n"
+ "\r\n"
+ "#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)\r\n"
+ "#ifdef _WIN32\r\n"
+ "LANGUAGE 9, 1\r\n"
+ "#pragma code_page(1252)\r\n"
+ "#endif\r\n"
+ "#include ""res\\WindozeCE.rc2"" // non-Microsoft Visual C++ edited resources\r\n"
+ "#include ""afxres.rc"" // Standard components\r\n"
+ "#include ""wceres.rc"" // WCE-specific components\r\n"
+ "#endif\0"
+END
+
+#endif // APSTUDIO_INVOKED
+
+
+/////////////////////////////////////////////////////////////////////////////
+//
+// Icon
+//
+
+// Icon with lowest ID value placed first to ensure application icon
+// remains consistent on all systems.
+IDR_MAINFRAME ICON DISCARDABLE "res\\WindozeCE.ico"
+
+/////////////////////////////////////////////////////////////////////////////
+//
+// Dialog
+//
+
+IDD_WINDOZECE_DIALOG DIALOGEX 0, 0, 285, 111
+STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
+EXSTYLE WS_EX_APPWINDOW | WS_EX_CAPTIONOKBTN
+CAPTION "WindozeCE"
+FONT 8, "Tahoma"
+BEGIN
+ EDITTEXT IDC_PROGRAM_OUTPUT,7,7,271,79,ES_MULTILINE |
+ ES_AUTOVSCROLL | ES_READONLY | WS_VSCROLL
+ DEFPUSHBUTTON "Run",IDC_RUN,7,90,50,14
+ EDITTEXT IDC_PROGRAM_ARGUMENTS,61,90,217,14,ES_AUTOHSCROLL
+END
+
+
+#ifndef _MAC
+/////////////////////////////////////////////////////////////////////////////
+//
+// Version
+//
+
+VS_VERSION_INFO VERSIONINFO
+ FILEVERSION 1,0,0,1
+ PRODUCTVERSION 1,0,0,1
+ FILEFLAGSMASK 0x3fL
+#ifdef _DEBUG
+ FILEFLAGS 0x1L
+#else
+ FILEFLAGS 0x0L
+#endif
+ FILEOS 0x4L
+ FILETYPE 0x1L
+ FILESUBTYPE 0x0L
+BEGIN
+ BLOCK "StringFileInfo"
+ BEGIN
+ BLOCK "040904B0"
+ BEGIN
+ VALUE "CompanyName", "\0"
+ VALUE "FileDescription", "WindozeCE WCE MFC Application\0"
+ VALUE "FileVersion", "1, 0, 0, 1\0"
+ VALUE "InternalName", "WindozeCE\0"
+ VALUE "LegalCopyright", "Copyright (C) 1998\0"
+ VALUE "LegalTrademarks", "\0"
+ VALUE "OriginalFilename", "WindozeCE.EXE\0"
+ VALUE "ProductName", "WindozeCE Application\0"
+ VALUE "ProductVersion", "1, 0, 0, 1\0"
+ END
+ END
+ BLOCK "VarFileInfo"
+ BEGIN
+ VALUE "Translation", 0x409, 1200
+ END
+END
+
+#endif // !_MAC
+
+
+/////////////////////////////////////////////////////////////////////////////
+//
+// DESIGNINFO
+//
+
+#ifdef APSTUDIO_INVOKED
+GUIDELINES DESIGNINFO DISCARDABLE
+BEGIN
+ IDD_WINDOZECE_DIALOG, DIALOG
+ BEGIN
+ LEFTMARGIN, 7
+ RIGHTMARGIN, 278
+ TOPMARGIN, 7
+ BOTTOMMARGIN, 104
+ END
+END
+#endif // APSTUDIO_INVOKED
+
+#endif // English (U.S.) resources
+/////////////////////////////////////////////////////////////////////////////
+
+
+
+#ifndef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 3 resource.
+//
+#define _AFX_NO_SPLITTER_RESOURCES
+#define _AFX_NO_OLE_RESOURCES
+#define _AFX_NO_TRACKER_RESOURCES
+#define _AFX_NO_PROPERTY_RESOURCES
+
+#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
+#ifdef _WIN32
+LANGUAGE 9, 1
+#pragma code_page(1252)
+#endif
+#include "res\WindozeCE.rc2" // non-Microsoft Visual C++ edited resources
+#include "afxres.rc" // Standard components
+#include "wceres.rc" // WCE-specific components
+#endif
+/////////////////////////////////////////////////////////////////////////////
+#endif // not APSTUDIO_INVOKED
+
diff --git a/WindozeCE/WindozeCEDlg.cpp b/WindozeCE/WindozeCEDlg.cpp
new file mode 100644
index 00000000000..bc77803ddf8
--- /dev/null
+++ b/WindozeCE/WindozeCEDlg.cpp
@@ -0,0 +1,156 @@
+// $Id$
+// WindozeCEDlg.cpp : implementation file
+//
+
+#include "stdafx.h"
+#include "WindozeCE.h"
+#include "WindozeCEDlg.h"
+#include "ace/ARGV.h"
+#include "ACEApp.h"
+
+#ifdef _DEBUG
+#define new DEBUG_NEW
+#undef THIS_FILE
+static char THIS_FILE[] = __FILE__;
+#endif
+
+static CWnd *host_window_ = 0;
+
+UINT worker (void * arg)
+{
+ ACE_ARGV cmd_line ((TCHAR *) arg);
+ extern int ace_ce_main (int, ASYS_TCHAR *[]);
+
+ int retv = ace_ce_main (cmd_line.argc (), cmd_line.argv ());
+ host_window_->SetDlgItemText (IDC_RUN, TEXT ("Stopped"));
+
+ return retv;
+
+ // Sleep (500);
+ // for (size_t i = 0; i < cmd_line.argc (); i++, Sleep (500))
+ // ACE_DEBUG ((LM_DEBUG, TEXT ("The %d command arg is \"%s\""),
+ // i, cmd_line.argv ()[i]));
+
+ // return 0;
+ // CString *msg = 0;
+ // while (1)
+ // {
+ // Sleep (500);
+ // msg = new CString;
+ // SYSTEMTIME curtime;
+ // GetLocalTime (&curtime);
+ // msg->Format (TEXT ("Time: %02d:%02d:%02d.%03d"), curtime.wHour,
+ // curtime.wMinute, curtime.wSecond,
+ // curtime.wMilliseconds);
+ // ACE_DEBUG ((LM_DEBUG, TEXT ("(%P|%t) Test logging: %s\n"), *msg));
+ // delete msg;
+ // }
+ // return 0;
+}
+
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEDlg dialog
+
+CWindozeCEDlg::CWindozeCEDlg(CWnd* pParent /*=NULL*/)
+ : CDialog(CWindozeCEDlg::IDD, pParent)
+{
+ //{{AFX_DATA_INIT(CWindozeCEDlg)
+ // NOTE: the ClassWizard will add member initialization here
+ //}}AFX_DATA_INIT
+ // Note that LoadIcon does not require a subsequent DestroyIcon in Win32
+ m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
+}
+
+void CWindozeCEDlg::DoDataExchange(CDataExchange* pDX)
+{
+ CDialog::DoDataExchange(pDX);
+ //{{AFX_DATA_MAP(CWindozeCEDlg)
+ // NOTE: the ClassWizard will add DDX and DDV calls here
+ //}}AFX_DATA_MAP
+}
+
+BEGIN_MESSAGE_MAP(CWindozeCEDlg, CDialog)
+ //{{AFX_MSG_MAP(CWindozeCEDlg)
+ ON_WM_TIMER()
+ ON_BN_CLICKED(IDC_RUN, OnStart)
+ //}}AFX_MSG_MAP
+ END_MESSAGE_MAP()
+
+ /////////////////////////////////////////////////////////////////////////////
+ // CWindozeCEDlg message handlers
+
+ BOOL CWindozeCEDlg::OnInitDialog()
+{
+ CDialog::OnInitDialog();
+
+ // Set the icon for this dialog. The framework does this automatically
+ // when the application's main window is not a dialog
+ SetIcon(m_hIcon, TRUE); // Set big icon
+ SetIcon(m_hIcon, FALSE); // Set small icon
+
+ this->SetDlgItemText (IDC_PROGRAM_OUTPUT,
+ TEXT ("A really long string that will hopefully show whether this kind of string can be fit and wrap around a simple TEXT object within a Dialog box. If this doesn't work, we'll see what to do next."));
+ CenterWindow(GetDesktopWindow()); // center to the hpc screen
+
+ this->ace.set_window (this, NC_ACE_NOTIFY, INC_ACE_LOGMSG);
+ this->ace.set_self_default ();
+ host_window_ = this;
+ return TRUE; // return TRUE unless you set the focus to a control
+}
+
+BOOL CWindozeCEDlg::OnCommand(WPARAM wParam, LPARAM lParam)
+{
+ static BOOL got_cmd = FALSE;
+ int notify = HIBYTE (wParam);
+ int id = LOBYTE (wParam);
+
+ if (notify == NC_ACE_NOTIFY && id == INC_ACE_LOGMSG)
+ {
+ CString *msg = (CString *) lParam ;
+ LPTSTR head = (LPTSTR) ((LPCTSTR) *msg);
+ CString newbuf;
+
+ LPTSTR newline;
+
+ while ((newline = ACE_OS::strchr (head, '\n')) != NULL)
+ {
+ *newline = 0;
+ newbuf += head;
+ newbuf += "\r\n";
+ head = newline+1;
+ }
+
+ newbuf += head;
+
+ CEdit *editor = (CEdit *) GetDlgItem (IDC_PROGRAM_OUTPUT);
+ editor -> ReplaceSel (newbuf);
+
+ delete msg;
+ return TRUE;
+ }
+ return CDialog::OnCommand(wParam, lParam);
+}
+
+void CWindozeCEDlg::OnTimer(UINT nIDEvent)
+{
+ // CWnd *text = this->GetDlgItem (IDC_TEXT_DISP);
+ // text->ModifyStyle (WS_VISIBLE, SS_CENTER, 0);
+ // this->UpdateWindow ();
+
+ CDialog::OnTimer(nIDEvent);
+}
+
+void CWindozeCEDlg::OnStart()
+{
+ static BOOL once = FALSE;
+
+ if (! once)
+ {
+ CString cmdline;
+ this->GetDlgItemText (IDC_PROGRAM_ARGUMENTS, cmdline);
+ AfxBeginThread (worker, (void *) (LPCTSTR) cmdline);
+ this->SetDlgItemText (IDC_RUN, TEXT ("Running..."));
+ once = TRUE;
+ }
+}
diff --git a/WindozeCE/resource.h b/WindozeCE/resource.h
index 994bd3e4f6c..174cf16aba9 100644
--- a/WindozeCE/resource.h
+++ b/WindozeCE/resource.h
@@ -1,13 +1,13 @@
// $Id$
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
-// Used by WinAdapter.rc
+// Used by WindozeCE.rc
//
-#define IDD_WinAdapter_DIALOG 102
+#define IDD_WINDOZECE_DIALOG 102
#define IDR_MAINFRAME 128
-#define IDC_TEXT_DISP 1001
-#define IDC_CMDLINE 1005
-#define IDC_START 1007
+#define IDC_PROGRAM_OUTPUT 1001
+#define IDC_RUN 1003
+#define IDC_PROGRAM_ARGUMENTS 1004
// Next default values for new objects
//
@@ -15,7 +15,7 @@
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE 129
#define _APS_NEXT_COMMAND_VALUE 32771
-#define _APS_NEXT_CONTROL_VALUE 1008
+#define _APS_NEXT_CONTROL_VALUE 1005
#define _APS_NEXT_SYMED_VALUE 101
#endif
#endif
diff --git a/WindozeCE/windoze.cfg b/WindozeCE/windoze.cfg
deleted file mode 100644
index 80c479b3205..00000000000
--- a/WindozeCE/windoze.cfg
+++ /dev/null
@@ -1 +0,0 @@
-WCE_CFG=WCE200; \ No newline at end of file
diff --git a/WindozeCE/windoze.dsp b/WindozeCE/windoze.dsp
deleted file mode 100644
index dd0b416b1bb..00000000000
--- a/WindozeCE/windoze.dsp
+++ /dev/null
@@ -1,413 +0,0 @@
-# Microsoft Developer Studio Project File - Name="windoez" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 5.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (WCE SH) Static Library" 0x0904
-# TARGTYPE "Win32 (WCE MIPS) Static Library" 0x0a04
-# TARGTYPE "Win32 (WCE x86em) Static Library" 0x0b04
-
-CFG=windoez - Win32 (WCE x86em) Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE
-!MESSAGE NMAKE /f "windoez.mak".
-!MESSAGE
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE
-!MESSAGE NMAKE /f "windoez.mak" CFG="windoez - Win32 (WCE x86em) Debug"
-!MESSAGE
-!MESSAGE Possible choices for configuration are:
-!MESSAGE
-!MESSAGE "windoez - Win32 (WCE x86em) Release" (based on\
- "Win32 (WCE x86em) Static Library")
-!MESSAGE "windoez - Win32 (WCE x86em) Debug" (based on\
- "Win32 (WCE x86em) Static Library")
-!MESSAGE "windoez - Win32 (WCE MIPS) Release" (based on\
- "Win32 (WCE MIPS) Static Library")
-!MESSAGE "windoez - Win32 (WCE MIPS) Debug" (based on\
- "Win32 (WCE MIPS) Static Library")
-!MESSAGE "windoez - Win32 (WCE SH) Release" (based on\
- "Win32 (WCE SH) Static Library")
-!MESSAGE "windoez - Win32 (WCE SH) Debug" (based on\
- "Win32 (WCE SH) Static Library")
-!MESSAGE
-
-# Begin Project
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-
-!IF "$(CFG)" == "windoez - Win32 (WCE x86em) Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "x86emRel"
-# PROP BASE Intermediate_Dir "x86emRel"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "x86emRel"
-# PROP Intermediate_Dir "x86emRel"
-# PROP Target_Dir ""
-CPP=cl.exe
-# ADD BASE CPP /nologo /W3 /O2 /D "UNDER_CE" /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=200 /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "NDEBUG" /D "x86" /D "i486" /D "_x86_" /YX /c
-# ADD CPP /nologo /MT /W3 /O2 /I "..\\" /D "_UNICODE" /D "WIN32" /D "STRICT" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "NDEBUG" /D "x86" /D "i486" /D "_x86_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /YX /c
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE x86em) Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "x86emDbg"
-# PROP BASE Intermediate_Dir "x86emDbg"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "x86emDbg"
-# PROP Intermediate_Dir "x86emDbg"
-# PROP Target_Dir ""
-CPP=cl.exe
-# ADD BASE CPP /nologo /W3 /Z7 /Od /D "UNDER_CE" /D "UNICODE" /D "_UNICODE" /D "WIN32" /D "STRICT" /D _WIN32_WCE=200 /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "_DEBUG" /D "x86" /D "i486" /D "_x86_" /YX /c
-# ADD CPP /nologo /MTd /W3 /Z7 /Od /I "..\\" /D "_UNICODE" /D "WIN32" /D "STRICT" /D "_WIN32_WCE_EMULATION" /D "INTERNATIONAL" /D "USA" /D "INTLMSG_CODEPAGE" /D "_DEBUG" /D "x86" /D "i486" /D "_x86_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /YX /c
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "WMIPSRel"
-# PROP BASE Intermediate_Dir "WMIPSRel"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "WMIPSRel"
-# PROP Intermediate_Dir "WMIPSRel"
-# PROP Target_Dir ""
-CPP=clmips.exe
-# ADD BASE CPP /nologo /ML /W3 /O2 /D "NDEBUG" /D "MIPS" /D "_MIPS_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /YX /QMRWCE /c
-# ADD CPP /nologo /MT /W3 /O2 /I "..\\" /D "NDEBUG" /D "MIPS" /D "_MIPS_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /YX /QMRWCE /c
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "WMIPSDbg"
-# PROP BASE Intermediate_Dir "WMIPSDbg"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "WMIPSDbg"
-# PROP Intermediate_Dir "WMIPSDbg"
-# PROP Target_Dir ""
-CPP=clmips.exe
-# ADD BASE CPP /nologo /MLd /W3 /Zi /Od /D "DEBUG" /D "MIPS" /D "_MIPS_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /YX /QMRWCE /c
-# ADD CPP /nologo /MTd /W3 /Zi /Od /I "..\\" /D "DEBUG" /D "MIPS" /D "_MIPS_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /YX /QMRWCE /c
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "WCESHRel"
-# PROP BASE Intermediate_Dir "WCESHRel"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "WCESHRel"
-# PROP Intermediate_Dir "WCESHRel"
-# PROP Target_Dir ""
-CPP=shcl.exe
-# ADD BASE CPP /nologo /ML /W3 /O2 /D "NDEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /YX /c
-# ADD CPP /nologo /MT /W3 /O2 /I "..\\" /D "NDEBUG" /D "SHx" /D "SH3" /D "_SH3_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /YX /c
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "WCESHDbg"
-# PROP BASE Intermediate_Dir "WCESHDbg"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 2
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "WCESHDbg"
-# PROP Intermediate_Dir "WCESHDbg"
-# PROP Target_Dir ""
-CPP=shcl.exe
-# ADD BASE CPP /nologo /MLd /W3 /Zi /Od /D "DEBUG" /D "SH3" /D "_SH3_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /YX /c
-# ADD CPP /nologo /MTd /W3 /Zi /Od /I "..\\" /D "DEBUG" /D "SH3" /D "_SH3_" /D "UNDER_CE" /D "UNICODE" /D _WIN32_WCE=200 /D ACE_HAS_MFC=1 /D ACE_HAS_WINCE=1 /D "_AFXDLL" /c
-# SUBTRACT CPP /Gy /YX
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LIB32=link.exe -lib
-# ADD BASE LIB32 /nologo
-# ADD LIB32 /nologo
-
-!ENDIF
-
-# Begin Target
-
-# Name "windoez - Win32 (WCE x86em) Release"
-# Name "windoez - Win32 (WCE x86em) Debug"
-# Name "windoez - Win32 (WCE MIPS) Release"
-# Name "windoez - Win32 (WCE MIPS) Debug"
-# Name "windoez - Win32 (WCE SH) Release"
-# Name "windoez - Win32 (WCE SH) Debug"
-# Begin Source File
-
-SOURCE=.\ACEApp.cpp
-
-!IF "$(CFG)" == "windoez - Win32 (WCE x86em) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE x86em) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Debug"
-
-DEP_CPP_ACEAP=\
- "..\ace\ACE.h"\
- "..\ace\ACE.i"\
- "..\ace\Auto_Ptr.cpp"\
- "..\ace\Auto_Ptr.h"\
- "..\ace\Auto_Ptr.i"\
- "..\ace\Basic_Types.h"\
- "..\ace\Basic_Types.i"\
- "..\ace\config-win32-common.h"\
- "..\ace\config-win32.h"\
- "..\ace\config-WinCE.h"\
- "..\ace\config.h"\
- "..\ace\inc_user_config.h"\
- "..\ace\iosfwd.h"\
- "..\ace\Log_Msg.h"\
- "..\ace\Log_Priority.h"\
- "..\ace\Log_Record.h"\
- "..\ace\Log_Record.i"\
- "..\ace\Managed_Object.cpp"\
- "..\ace\Managed_Object.h"\
- "..\ace\Managed_Object.i"\
- "..\ace\Object_Manager.h"\
- "..\ace\Object_Manager.i"\
- "..\ace\OS.h"\
- "..\ace\OS.i"\
- "..\ace\SString.h"\
- "..\ace\SString.i"\
- "..\ace\streams.h"\
- "..\ace\sys_conf.h"\
- "..\ace\Trace.h"\
- "..\ace\Version.h"\
- "..\ace\ws2tcpip.h"\
- ".\ACEApp.h"\
- ".\stdafx.h"\
-
-
-!ENDIF
-
-# End Source File
-# Begin Source File
-
-SOURCE=.\StdAfx.cpp
-
-!IF "$(CFG)" == "windoez - Win32 (WCE x86em) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE x86em) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Debug"
-
-DEP_CPP_STDAF=\
- ".\stdafx.h"\
-
-
-!ENDIF
-
-# End Source File
-# Begin Source File
-
-SOURCE=.\WinAdapter.cpp
-
-!IF "$(CFG)" == "windoez - Win32 (WCE x86em) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE x86em) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Debug"
-
-DEP_CPP_WINAD=\
- "..\ace\ACE.h"\
- "..\ace\ACE.i"\
- "..\ace\Auto_Ptr.cpp"\
- "..\ace\Auto_Ptr.h"\
- "..\ace\Auto_Ptr.i"\
- "..\ace\Basic_Types.h"\
- "..\ace\Basic_Types.i"\
- "..\ace\config-win32-common.h"\
- "..\ace\config-win32.h"\
- "..\ace\config-WinCE.h"\
- "..\ace\config.h"\
- "..\ace\inc_user_config.h"\
- "..\ace\iosfwd.h"\
- "..\ace\Log_Msg.h"\
- "..\ace\Log_Priority.h"\
- "..\ace\Log_Record.h"\
- "..\ace\Log_Record.i"\
- "..\ace\Managed_Object.cpp"\
- "..\ace\Managed_Object.h"\
- "..\ace\Managed_Object.i"\
- "..\ace\Object_Manager.h"\
- "..\ace\Object_Manager.i"\
- "..\ace\OS.h"\
- "..\ace\OS.i"\
- "..\ace\SString.h"\
- "..\ace\SString.i"\
- "..\ace\streams.h"\
- "..\ace\sys_conf.h"\
- "..\ace\Trace.h"\
- "..\ace\Version.h"\
- "..\ace\ws2tcpip.h"\
- ".\ACEApp.h"\
- ".\stdafx.h"\
- ".\WinAdapter.h"\
- ".\WinAdapterDlg.h"\
-
-
-!ENDIF
-
-# End Source File
-# Begin Source File
-
-SOURCE=.\WinAdapter.rc
-# End Source File
-# Begin Source File
-
-SOURCE=.\WinAdapterDlg.cpp
-
-!IF "$(CFG)" == "windoez - Win32 (WCE x86em) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE x86em) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE MIPS) Debug"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Release"
-
-!ELSEIF "$(CFG)" == "windoez - Win32 (WCE SH) Debug"
-
-DEP_CPP_WINADA=\
- "..\ace\ACE.h"\
- "..\ace\ACE.i"\
- "..\ace\ARGV.h"\
- "..\ace\ARGV.i"\
- "..\ace\Atomic_Op.i"\
- "..\ace\Auto_Ptr.cpp"\
- "..\ace\Auto_Ptr.h"\
- "..\ace\Auto_Ptr.i"\
- "..\ace\Basic_Types.h"\
- "..\ace\Basic_Types.i"\
- "..\ace\config-win32-common.h"\
- "..\ace\config-win32.h"\
- "..\ace\config-WinCE.h"\
- "..\ace\config.h"\
- "..\ace\Containers.cpp"\
- "..\ace\Containers.h"\
- "..\ace\Containers.i"\
- "..\ace\Event_Handler.h"\
- "..\ace\Event_Handler.i"\
- "..\ace\Free_List.cpp"\
- "..\ace\Free_List.h"\
- "..\ace\Free_List.i"\
- "..\ace\inc_user_config.h"\
- "..\ace\iosfwd.h"\
- "..\ace\Log_Msg.h"\
- "..\ace\Log_Priority.h"\
- "..\ace\Log_Record.h"\
- "..\ace\Log_Record.i"\
- "..\ace\Malloc.h"\
- "..\ace\Malloc.i"\
- "..\ace\Malloc_T.cpp"\
- "..\ace\Malloc_T.h"\
- "..\ace\Malloc_T.i"\
- "..\ace\Managed_Object.cpp"\
- "..\ace\Managed_Object.h"\
- "..\ace\Managed_Object.i"\
- "..\ace\Mem_Map.h"\
- "..\ace\Mem_Map.i"\
- "..\ace\Memory_Pool.h"\
- "..\ace\Memory_Pool.i"\
- "..\ace\Object_Manager.h"\
- "..\ace\Object_Manager.i"\
- "..\ace\OS.h"\
- "..\ace\OS.i"\
- "..\ace\Signal.h"\
- "..\ace\Signal.i"\
- "..\ace\SString.h"\
- "..\ace\SString.i"\
- "..\ace\streams.h"\
- "..\ace\SV_Semaphore_Complex.h"\
- "..\ace\SV_Semaphore_Complex.i"\
- "..\ace\SV_Semaphore_Simple.h"\
- "..\ace\SV_Semaphore_Simple.i"\
- "..\ace\Synch.h"\
- "..\ace\Synch.i"\
- "..\ace\Synch_T.cpp"\
- "..\ace\Synch_T.h"\
- "..\ace\Synch_T.i"\
- "..\ace\sys_conf.h"\
- "..\ace\Thread.h"\
- "..\ace\Thread.i"\
- "..\ace\Trace.h"\
- "..\ace\Version.h"\
- "..\ace\ws2tcpip.h"\
- ".\ACEApp.h"\
- ".\stdafx.h"\
- ".\WinAdapter.h"\
- ".\WinAdapterDlg.h"\
-
-
-!ENDIF
-
-# End Source File
-# End Target
-# End Project
diff --git a/WindozeCE/windoze.dsw b/WindozeCE/windoze.dsw
deleted file mode 100644
index 22278507ca8..00000000000
--- a/WindozeCE/windoze.dsw
+++ /dev/null
@@ -1,29 +0,0 @@
-Microsoft Developer Studio Workspace File, Format Version 5.00
-# WARNING: DO NOT EDIT OR DELETE THIS WORKSPACE FILE!
-
-###############################################################################
-
-Project: "windoez"=.\windoez.dsp - Package Owner=<4>
-
-Package=<5>
-{{{
-}}}
-
-Package=<4>
-{{{
-}}}
-
-###############################################################################
-
-Global:
-
-Package=<5>
-{{{
-}}}
-
-Package=<3>
-{{{
-}}}
-
-###############################################################################
-
diff --git a/WindozeCE/WinAdapter.cpp b/WindozeCE/WindozeCE.cpp
index dfa7eed8919..a08128041f4 100644
--- a/WindozeCE/WinAdapter.cpp
+++ b/WindozeCE/WindozeCE.cpp
@@ -1,71 +1,70 @@
-// $Id$
-// WinAdapter.cpp : Defines the class behaviors for the application.
-//
-
-#include "stdafx.h"
-#include "WinAdapter.h"
-#include "WinAdapterDlg.h"
-#include "ACEApp.h"
-
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-#endif
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterApp
-
-BEGIN_MESSAGE_MAP(CWinAdapterApp, CWinApp)
- //{{AFX_MSG_MAP(CWinAdapterApp)
- // NOTE - the ClassWizard will add and remove mapping macros here.
- // DO NOT EDIT what you see in these blocks of generated code!
- //}}AFX_MSG
-END_MESSAGE_MAP()
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterApp construction
-
-CWinAdapterApp::CWinAdapterApp(LPCTSTR lpszAppName)
- : CWinApp(lpszAppName)
-{
- // TODO: add construction code here,
- // Place all significant initialization in InitInstance
-}
-
-/////////////////////////////////////////////////////////////////////////////
-// The one and only CWinAdapterApp object
-
-// WCE MFC apps require the application name to be specified in the CWinApp
-// constructor. A help contents filename may also be specified.
-
-CWinAdapterApp theApp(_T("WinAdapter"));
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterApp initialization
-
-BOOL CWinAdapterApp::InitInstance()
-{
- // Standard initialization
- // If you are not using these features and wish to reduce the size
- // of your final executable, you should remove from the following
- // the specific initialization routines you do not need.
-
- CWinAdapterDlg dlg;
- m_pMainWnd = &dlg;
- int nResponse = dlg.DoModal();
- if (nResponse == IDOK)
- {
- // TODO: Place code here to handle when the dialog is
- // dismissed with OK
- }
- else if (nResponse == IDCANCEL)
- {
- // TODO: Place code here to handle when the dialog is
- // dismissed with Cancel
- }
-
- // Since the dialog has been closed, return FALSE so that we exit the
- // application, rather than start the application's message pump.
- return FALSE;
-}
+// $Id$
+// WindozeCE.cpp : Defines the class behaviors for the application.
+//
+
+#include "stdafx.h"
+#include "WindozeCE.h"
+#include "WindozeCEDlg.h"
+
+#ifdef _DEBUG
+#define new DEBUG_NEW
+#undef THIS_FILE
+static char THIS_FILE[] = __FILE__;
+#endif
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEApp
+
+BEGIN_MESSAGE_MAP(CWindozeCEApp, CWinApp)
+ //{{AFX_MSG_MAP(CWindozeCEApp)
+ // NOTE - the ClassWizard will add and remove mapping macros here.
+ // DO NOT EDIT what you see in these blocks of generated code!
+ //}}AFX_MSG
+END_MESSAGE_MAP()
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEApp construction
+
+CWindozeCEApp::CWindozeCEApp(LPCTSTR lpszAppName)
+ : CWinApp(lpszAppName)
+{
+ // TODO: add construction code here,
+ // Place all significant initialization in InitInstance
+}
+
+/////////////////////////////////////////////////////////////////////////////
+// The one and only CWindozeCEApp object
+
+// WCE MFC apps require the application name to be specified in the CWinApp
+// constructor. A help contents filename may also be specified.
+
+CWindozeCEApp theApp(_T("WindozeCE"));
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEApp initialization
+
+BOOL CWindozeCEApp::InitInstance()
+{
+ // Standard initialization
+ // If you are not using these features and wish to reduce the size
+ // of your final executable, you should remove from the following
+ // the specific initialization routines you do not need.
+
+ CWindozeCEDlg dlg;
+ m_pMainWnd = &dlg;
+ int nResponse = dlg.DoModal();
+ if (nResponse == IDOK)
+ {
+ // TODO: Place code here to handle when the dialog is
+ // dismissed with OK
+ }
+ else if (nResponse == IDCANCEL)
+ {
+ // TODO: Place code here to handle when the dialog is
+ // dismissed with Cancel
+ }
+
+ // Since the dialog has been closed, return FALSE so that we exit the
+ // application, rather than start the application's message pump.
+ return FALSE;
+}
diff --git a/WindozeCE/WinAdapter.h b/WindozeCE/WindozeCE.h
index abf7d256aff..0252c250b3e 100644
--- a/WindozeCE/WinAdapter.h
+++ b/WindozeCE/WindozeCE.h
@@ -1,50 +1,50 @@
-// $Id$
-// WinAdapter.h : main header file for the WinAdapter application
-//
-
-#if !defined(AFX_WinAdapter_H__5088F846_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
-#define AFX_WinAdapter_H__5088F846_CE8B_11D1_9621_0040054CF0F0__INCLUDED_
-
-#if _MSC_VER >= 1000
-#pragma once
-#endif // _MSC_VER >= 1000
-
-#ifndef __AFXWIN_H__
- #error include 'stdafx.h' before including this file for PCH
-#endif
-
-#include "resource.h" // main symbols
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterApp:
-// See WinAdapter.cpp for the implementation of this class
-//
-
-class CWinAdapterApp : public CWinApp
-{
-public:
- CWinAdapterApp(LPCTSTR lpszAppName);
-
-// Overrides
- // ClassWizard generated virtual function overrides
- //{{AFX_VIRTUAL(CWinAdapterApp)
- public:
- virtual BOOL InitInstance();
- //}}AFX_VIRTUAL
-
-// Implementation
-
- //{{AFX_MSG(CWinAdapterApp)
- // NOTE - the ClassWizard will add and remove member functions here.
- // DO NOT EDIT what you see in these blocks of generated code !
- //}}AFX_MSG
- DECLARE_MESSAGE_MAP()
-};
-
-
-/////////////////////////////////////////////////////////////////////////////
-
-//{{AFX_INSERT_LOCATION}}
-// Microsoft Developer Studio will insert additional declarations immediately before the previous line.
-
-#endif // !defined(AFX_WinAdapter_H__5088F846_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
+// $Id$
+// WindozeCE.h : main header file for the WINDOZECE application
+//
+
+#if !defined(AFX_WINDOZECE_H__37544C69_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)
+#define AFX_WINDOZECE_H__37544C69_E3BC_11D1_968E_0040054CF0F0__INCLUDED_
+
+#if _MSC_VER >= 1000
+#pragma once
+#endif // _MSC_VER >= 1000
+
+#ifndef __AFXWIN_H__
+ #error include 'stdafx.h' before including this file for PCH
+#endif
+
+#include "resource.h" // main symbols
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEApp:
+// See WindozeCE.cpp for the implementation of this class
+//
+
+class CWindozeCEApp : public CWinApp
+{
+public:
+ CWindozeCEApp(LPCTSTR lpszAppName);
+
+// Overrides
+ // ClassWizard generated virtual function overrides
+ //{{AFX_VIRTUAL(CWindozeCEApp)
+ public:
+ virtual BOOL InitInstance();
+ //}}AFX_VIRTUAL
+
+// Implementation
+
+ //{{AFX_MSG(CWindozeCEApp)
+ // NOTE - the ClassWizard will add and remove member functions here.
+ // DO NOT EDIT what you see in these blocks of generated code !
+ //}}AFX_MSG
+ DECLARE_MESSAGE_MAP()
+};
+
+
+/////////////////////////////////////////////////////////////////////////////
+
+//{{AFX_INSERT_LOCATION}}
+// Microsoft Developer Studio will insert additional declarations immediately before the previous line.
+
+#endif // !defined(AFX_WINDOZECE_H__37544C69_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)
diff --git a/WindozeCE/WinAdapterDlg.h b/WindozeCE/WindozeCEDlg.h
index 85ed45d6429..d141e218117 100644
--- a/WindozeCE/WinAdapterDlg.h
+++ b/WindozeCE/WindozeCEDlg.h
@@ -1,54 +1,54 @@
-// $Id$
-// WinAdapterDlg.h : header file
-//
-
-#include "ace/OS.h"
-
-#if !defined(AFX_WinAdapterDLG_H__5088F848_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
-#define AFX_WinAdapterDLG_H__5088F848_CE8B_11D1_9621_0040054CF0F0__INCLUDED_
-
-#if _MSC_VER >= 1000
-#pragma once
-#endif // _MSC_VER >= 1000
-
-/////////////////////////////////////////////////////////////////////////////
-// CWinAdapterDlg dialog
-
-class CWinAdapterDlg : public CDialog
-{
- // Construction
-public:
- CWinAdapterDlg(CWnd* pParent = NULL); // standard constructor
-
- // Dialog Data
- //{{AFX_DATA(CWinAdapterDlg)
- enum { IDD = IDD_WinAdapter_DIALOG };
- // NOTE: the ClassWizard will add data members here
- //}}AFX_DATA
-
- // ClassWizard generated virtual function overrides
- //{{AFX_VIRTUAL(CWinAdapterDlg)
-protected:
- virtual void DoDataExchange(CDataExchange* pDX); // DDX/DDV support
- virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
- //}}AFX_VIRTUAL
-
- // Implementation
-protected:
- HICON m_hIcon;
-
- ACE_CE_Bridge ace;
-
- // Generated message map functions
- //{{AFX_MSG(CWinAdapterDlg)
- virtual BOOL OnInitDialog();
- afx_msg void OnTimer(UINT nIDEvent);
- afx_msg void OnStart();
- //}}AFX_MSG
- DECLARE_MESSAGE_MAP()
-};
-
-//{{AFX_INSERT_LOCATION}}
-// Microsoft Developer Studio will insert additional declarations immediately before the previous line.
-
-#endif // !defined(AFX_WinAdapterDLG_H__5088F848_CE8B_11D1_9621_0040054CF0F0__INCLUDED_)
+// $Id$
+// WindozeCEDlg.h : header file
+//
+
+#include "ace/OS.h"
+
+#if !defined(AFX_WINDOZECEDLG_H__37544C6B_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)
+#define AFX_WINDOZECEDLG_H__37544C6B_E3BC_11D1_968E_0040054CF0F0__INCLUDED_
+
+#if _MSC_VER >= 1000
+#pragma once
+#endif // _MSC_VER >= 1000
+
+/////////////////////////////////////////////////////////////////////////////
+// CWindozeCEDlg dialog
+
+class CWindozeCEDlg : public CDialog
+{
+ // Construction
+public:
+ CWindozeCEDlg(CWnd* pParent = NULL); // standard constructor
+
+ // Dialog Data
+ //{{AFX_DATA(CWindozeCEDlg)
+ enum { IDD = IDD_WINDOZECE_DIALOG };
+ // NOTE: the ClassWizard will add data members here
+ //}}AFX_DATA
+
+ // ClassWizard generated virtual function overrides
+ //{{AFX_VIRTUAL(CWindozeCEDlg)
+protected:
+ virtual void DoDataExchange(CDataExchange* pDX); // DDX/DDV support
+ virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
+ //}}AFX_VIRTUAL
+
+// Implementation
+protected:
+ HICON m_hIcon;
+
+ ACE_CE_Bridge ace;
+
+ // Generated message map functions
+ //{{AFX_MSG(CWindozeCEDlg)
+ virtual BOOL OnInitDialog();
+ afx_msg void OnTimer(UINT nIDEvent);
+ afx_msg void OnStart();
+ //}}AFX_MSG
+ DECLARE_MESSAGE_MAP()
+ };
+
+//{{AFX_INSERT_LOCATION}}
+// Microsoft Developer Studio will insert additional declarations immediately before the previous line.
+
+#endif // !defined(AFX_WINDOZECEDLG_H__37544C6B_E3BC_11D1_968E_0040054CF0F0__INCLUDED_)